<?php

namespace FiloBlu\ExtAmastyGeoipRedirect\Controller;

class Router implements \Magento\Framework\App\RouterInterface {

    /**
     * @var \Magento\Framework\App\ActionFactory
     */
    protected $actionFactory;
    protected $_helper;
    protected $scopeConfig;
    protected $storeManager;
    protected $urlBuilder;

    public function __construct(
    \Magento\Framework\App\ActionFactory $actionFactory,
    \FiloBlu\ExtAmastyGeoipRedirect\Helper\Data $helper,
    \Magento\Store\Model\StoreManagerInterface $storeManager,
    \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
    \Magento\Framework\UrlInterface $urlBuilder
    ) {
        $this->actionFactory = $actionFactory;
        $this->_helper = $helper;
        $this->storeManager = $storeManager;
        $this->scopeConfig = $scopeConfig;
        $this->urlBuilder = $urlBuilder;
    }

    public function match(\Magento\Framework\App\RequestInterface $request) {

        $currentStoreId = $this->storeManager->getStore()->getId();

        $currentPath = trim(parse_url($this->urlBuilder->getCurrentUrl(), PHP_URL_PATH));

        $isUserAgentToIgnore = false;

        $userAgent = $request->getHeader('USER_AGENT');
        $userAgentsIgnore = $this->scopeConfig->getValue('amgeoipredirect/restriction/user_agents_ignore');
        if (!empty($userAgentsIgnore)) {
            $userAgentsIgnore = explode(',', $userAgentsIgnore);
            $userAgentsIgnore = array_map("trim", $userAgentsIgnore);
            foreach ($userAgentsIgnore as $agent) {
                if ($userAgent && $agent && stripos($userAgent, $agent) !== false) {
                    $isUserAgentToIgnore = true;
                }
            }
        }

        if (!$this->scopeConfig->getValue('amgeoipredirect/general/enable', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId) ||
            $currentPath != "/" ||
            $request->getPathInfo() == "/geoip/index/landing/" ||
            !$this->scopeConfig->getValue('amgeoipredirect/landing/enable_landing', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId) ||
            ($this->scopeConfig->getValue('amgeoipredirect/landing/enable_landing', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId) && $this->scopeConfig->getValue('amgeoipredirect/landing/enable_landing_only_useragents_to_ignore', \Magento\Store\Model\ScopeInterface::SCOPE_STORES, $currentStoreId) && !$isUserAgentToIgnore)) {
            return;
        }

        $request->setAlias(\Magento\Framework\UrlInterface::REWRITE_REQUEST_PATH_ALIAS, $currentPath);
        $request->setPathInfo('/geoip/index/landing/');

        return $this->actionFactory->create('Magento\Framework\App\Action\Forward');


    }
}
